@@ -1,6 +1,7 @@
 import json
 from dicttoxml import dicttoxml
 from dict2xml import dict2xml
+from string_utils.validation import is_integer, is_decimal
 
 
 def format_output(obj, output_format, pretty_print, xml_library):
@@ -20,3 +21,16 @@ def format_output(obj, output_format, pretty_print, xml_library):
         output = obj
 
     return output
+
+
+def cast(string: str):
+    string = string.strip()
+
+    if is_integer(string):
+        return int(string)
+    elif is_decimal(string):
+        return float(string)
+    elif string == '-':
+        return None
+    else:
+        return string
